@@ -88,9 +88,9 @@ class SFAddMenu(BrowserView):
         super(SFAddMenu, self).__init__(context, request)
         self.portal = getToolByName(self.context, 'portal_url').getPortalObject()
         self.portal_url = self.portal.absolute_url()
-        self.adapted = ISFBaseEventFields(self.context)
+        self.adapted = ISolgemaFullcalendarProperties(aq_inner(context), None)
         target_folder = getattr(self.adapted, 'target_folder', None)
-        self.addContext = target_folder and self.portal.restrictedTraverse('/'+self.portal.id+target_folder) or aq_parent(aq_inner(self.context))
+        self.addContext = target_folder and self.portal.unrestrictedTraverse('/'+self.portal.id+target_folder) or aq_parent(aq_inner(self.context))
         self.EventAllDay = self.request.get('EventAllDay', False)
         self.ReqAllDay = self.EventAllDay and '&EventAllDay='+self.EventAllDay or ''
         self.startDate = self.request.get('startDate', '')
